@@ -1,5 +1,5 @@
 /***************************************************************************
- *   2007-2024 by Peter Semiletov                                          *
+ *   2007-2025 by Peter Semiletov                                          *
  *   peter.semiletov@gmail.com                                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -1425,11 +1425,11 @@ QMenu* CDocument::createStandardContextMenu()
 
 bool CDocument::file_open (const QString &fileName, const QString &codec)
 {
-  //qDebug() << "CDocument::file_open " << fileName;
+  qDebug() << "CDocument::file_open " << fileName;
 
   CTio *tio = holder->tio_handler.get_for_fname (fileName);
 
-  //qDebug() << "tio->metaObject()->className()" << tio->metaObject()->className();
+//  qDebug() << "tio->metaObject()->className()" << tio->metaObject()->className();
 
   if (! tio)
       return false;
@@ -2606,9 +2606,9 @@ void CDox::add_to_recent (CDocument *d)
   s += "*";
 
   if (! d->get_word_wrap())
-     s+="0";
+     s+= "0";
   else
-      s+="1";
+      s+= "1";
 
   recent_files.prepend (s);
   if (recent_files.size() > recent_list_max_items)
@@ -2714,6 +2714,50 @@ CDocument* CDox::open_file (const QString &fileName, const QString &codec)
   return d;
 }
 
+CDocument* CDox::open_file_without_reload  (const QString &fileName, const QString &codec)
+{
+  if (! file_exists (fileName) || ! path_is_file (fileName))
+     return 0;
+
+  if (is_image (fileName))
+     {
+      CDocument *td = get_current();
+      if (td)
+         {
+          td->insert_image (fileName);
+          td->setFocus (Qt::OtherFocusReason);
+         }
+      return td;
+     }
+
+
+  CDocument *d = get_document_by_fname (fileName);
+  if (d)
+     {
+      tab_widget->setCurrentIndex (tab_widget->indexOf (d->tab_page));
+      //d->reload (codec);
+      return d;
+     }
+
+
+//else truly create the new doc
+  d = create_new();
+  d->file_open (fileName, codec);
+
+  dir_last = get_file_path (d->file_name);
+
+  d->update_status();
+  d->update_title (settings->value ("full_path_at_window_title", 1).toBool());
+
+  main_tab_widget->setCurrentIndex (0);
+
+  update_current_files_menu();
+
+  return d;
+}
+
+
+
 
 CDocument* CDox::open_file_triplex (const QString &triplex)
 {
@@ -2948,16 +2992,20 @@ void CDox::open_recent()
 {
   QAction *act = qobject_cast<QAction *>(sender());
 
-  QString t = act->text();
-  t.remove ("&");
+  //QString t = act->text();
+  QString t = act->data().toString();
 
-  //qDebug() << "t:" << t;
+  //t.remove ("&");
 
-  int i = recent_files.indexOf (t);
-  if (i == -1)
-     return;
+  qDebug() << "t:" << t;
+
+//  int i = recent_files.indexOf (t);
+//  if (i == -1)
+//     return;
+
+//  CDocument *d = open_file_triplex (recent_files[i]);
+  CDocument *d = open_file_triplex (t);
 
-  CDocument *d = open_file_triplex (recent_files[i]);
   if (d)
       dir_last = get_file_path (d->file_name);
 
